# fastfuels-core
Core algorithms for FastFuels

## FastFuels Platform

The algorithms and methods in fastfuels-core serve as the foundation for the FastFuels Platform and the FastFuelsAPI.
The FastFuels API is a JSON API that connects various data sources to the algorithms in fastfuels-core in order to create, modify, and export fuel data for use in fire behavior models.

Documentation for the FastFuels Platform, including reference documentation for the API can be found at the following links:

1) https://docs.fastfuels.silvxlabs.com/
2) https://api.fastfuels.silvxlabs.com/redoc
